==> ggeffects_1.2.3.tar.gz: ggeffects/tests/testthat/_snaps/print.md <==
# ggpredict, print

    Code
      print(ggpredict(fit, terms = c("c12hour", "neg_c_7", "c161sex")))
    Output
      # Predicted values of Total score BARTHEL INDEX
      
      # neg_c_7 = 8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.41 | [89.04, 99.77]
           45 |     91.36 | [85.91, 96.81]
           85 |     88.65 | [82.90, 94.40]
          170 |     82.89 | [75.94, 89.85]
      
      # neg_c_7 = 11.8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     90.60 | [85.18, 96.02]
           45 |     87.55 | [82.08, 93.03]
           85 |     84.85 | [79.09, 90.60]
          170 |     79.09 | [72.17, 86.00]
      
      # neg_c_7 = 15.7
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     86.70 | [80.89, 92.50]
           45 |     83.65 | [77.82, 89.48]
           85 |     80.94 | [74.87, 87.01]
          170 |     75.18 | [68.05, 82.32]
      
      # neg_c_7 = 8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.91 | [89.88, 99.95]
           45 |     91.86 | [86.78, 96.95]
           85 |     89.16 | [83.77, 94.54]
          170 |     83.40 | [76.79, 90.01]
      
      # neg_c_7 = 11.8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     91.11 | [86.06, 96.15]
           45 |     88.06 | [82.99, 93.13]
           85 |     85.35 | [80.01, 90.69]
          170 |     79.59 | [73.06, 86.12]
      
      # neg_c_7 = 15.7
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     87.20 | [81.78, 92.62]
           45 |     84.15 | [78.74, 89.57]
           85 |     81.44 | [75.80, 87.09]
          170 |     75.69 | [68.96, 82.42]
      
      Adjusted for:
      *  c82cop1 =                   3.13
      *   e42dep =            independent
      * c172code = low level of education
    Message <simpleMessage>
      
      Not all rows are shown in the ouput. Use `print(..., n = Inf)` to show
        all rows.

---

    Code
      print(ggpredict(fit, terms = c("c12hour", "neg_c_7", "c161sex")), n = Inf)
    Output
      # Predicted values of Total score BARTHEL INDEX
      
      # neg_c_7 = 8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.41 | [89.04, 99.77]
            5 |     94.07 | [88.71, 99.43]
           10 |     93.73 | [88.37, 99.09]
           15 |     93.39 | [88.03, 98.75]
           20 |     93.05 | [87.69, 98.42]
           25 |     92.71 | [87.34, 98.09]
           30 |     92.38 | [86.99, 97.76]
           35 |     92.04 | [86.63, 97.44]
           40 |     91.70 | [86.27, 97.12]
           45 |     91.36 | [85.91, 96.81]
           50 |     91.02 | [85.55, 96.50]
           55 |     90.68 | [85.18, 96.19]
           60 |     90.34 | [84.80, 95.88]
           65 |     90.01 | [84.43, 95.58]
           70 |     89.67 | [84.05, 95.28]
           75 |     89.33 | [83.67, 94.99]
           80 |     88.99 | [83.29, 94.69]
           85 |     88.65 | [82.90, 94.40]
           90 |     88.31 | [82.51, 94.12]
           95 |     87.97 | [82.11, 93.83]
          100 |     87.64 | [81.72, 93.55]
          105 |     87.30 | [81.32, 93.27]
          110 |     86.96 | [80.92, 93.00]
          115 |     86.62 | [80.52, 92.72]
          120 |     86.28 | [80.11, 92.45]
          125 |     85.94 | [79.70, 92.18]
          130 |     85.60 | [79.29, 91.92]
          135 |     85.26 | [78.88, 91.65]
          140 |     84.93 | [78.46, 91.39]
          145 |     84.59 | [78.05, 91.13]
          150 |     84.25 | [77.63, 90.87]
          155 |     83.91 | [77.21, 90.61]
          160 |     83.57 | [76.79, 90.36]
          165 |     83.23 | [76.36, 90.10]
          170 |     82.89 | [75.94, 89.85]
      
      # neg_c_7 = 11.8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     90.60 | [85.18, 96.02]
            5 |     90.26 | [84.85, 95.67]
           10 |     89.92 | [84.52, 95.33]
           15 |     89.59 | [84.18, 94.99]
           20 |     89.25 | [83.84, 94.65]
           25 |     88.91 | [83.49, 94.32]
           30 |     88.57 | [83.15, 93.99]
           35 |     88.23 | [82.79, 93.67]
           40 |     87.89 | [82.44, 93.35]
           45 |     87.55 | [82.08, 93.03]
           50 |     87.22 | [81.72, 92.71]
           55 |     86.88 | [81.35, 92.40]
           60 |     86.54 | [80.98, 92.09]
           65 |     86.20 | [80.61, 91.79]
           70 |     85.86 | [80.24, 91.48]
           75 |     85.52 | [79.86, 91.19]
           80 |     85.18 | [79.48, 90.89]
           85 |     84.85 | [79.09, 90.60]
           90 |     84.51 | [78.71, 90.31]
           95 |     84.17 | [78.32, 90.02]
          100 |     83.83 | [77.92, 89.74]
          105 |     83.49 | [77.53, 89.45]
          110 |     83.15 | [77.13, 89.18]
          115 |     82.81 | [76.73, 88.90]
          120 |     82.48 | [76.33, 88.63]
          125 |     82.14 | [75.92, 88.35]
          130 |     81.80 | [75.51, 88.08]
          135 |     81.46 | [75.10, 87.82]
          140 |     81.12 | [74.69, 87.55]
          145 |     80.78 | [74.27, 87.29]
          150 |     80.44 | [73.86, 87.03]
          155 |     80.10 | [73.44, 86.77]
          160 |     79.77 | [73.02, 86.51]
          165 |     79.43 | [72.60, 86.26]
          170 |     79.09 | [72.17, 86.00]
      
      # neg_c_7 = 15.7
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     86.70 | [80.89, 92.50]
            5 |     86.36 | [80.56, 92.15]
           10 |     86.02 | [80.23, 91.81]
           15 |     85.68 | [79.90, 91.46]
           20 |     85.34 | [79.56, 91.12]
           25 |     85.00 | [79.22, 90.79]
           30 |     84.66 | [78.87, 90.45]
           35 |     84.33 | [78.53, 90.13]
           40 |     83.99 | [78.17, 89.80]
           45 |     83.65 | [77.82, 89.48]
           50 |     83.31 | [77.46, 89.16]
           55 |     82.97 | [77.10, 88.84]
           60 |     82.63 | [76.74, 88.53]
           65 |     82.29 | [76.37, 88.22]
           70 |     81.96 | [76.00, 87.91]
           75 |     81.62 | [75.63, 87.61]
           80 |     81.28 | [75.25, 87.30]
           85 |     80.94 | [74.87, 87.01]
           90 |     80.60 | [74.49, 86.71]
           95 |     80.26 | [74.11, 86.42]
          100 |     79.92 | [73.72, 86.13]
          105 |     79.59 | [73.33, 85.84]
          110 |     79.25 | [72.94, 85.56]
          115 |     78.91 | [72.54, 85.28]
          120 |     78.57 | [72.14, 85.00]
          125 |     78.23 | [71.74, 84.72]
          130 |     77.89 | [71.34, 84.44]
          135 |     77.55 | [70.94, 84.17]
          140 |     77.21 | [70.53, 83.90]
          145 |     76.88 | [70.12, 83.63]
          150 |     76.54 | [69.71, 83.37]
          155 |     76.20 | [69.30, 83.10]
          160 |     75.86 | [68.88, 82.84]
          165 |     75.52 | [68.46, 82.58]
          170 |     75.18 | [68.05, 82.32]
      
      # neg_c_7 = 8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.91 | [89.88, 99.95]
            5 |     94.57 | [89.55, 99.60]
           10 |     94.23 | [89.22, 99.25]
           15 |     93.90 | [88.88, 98.91]
           20 |     93.56 | [88.54, 98.58]
           25 |     93.22 | [88.19, 98.25]
           30 |     92.88 | [87.84, 97.92]
           35 |     92.54 | [87.49, 97.59]
           40 |     92.20 | [87.13, 97.27]
           45 |     91.86 | [86.78, 96.95]
           50 |     91.53 | [86.41, 96.64]
           55 |     91.19 | [86.04, 96.33]
           60 |     90.85 | [85.67, 96.02]
           65 |     90.51 | [85.30, 95.72]
           70 |     90.17 | [84.92, 95.42]
           75 |     89.83 | [84.54, 95.12]
           80 |     89.49 | [84.16, 94.83]
           85 |     89.16 | [83.77, 94.54]
           90 |     88.82 | [83.38, 94.25]
           95 |     88.48 | [82.99, 93.97]
          100 |     88.14 | [82.59, 93.69]
          105 |     87.80 | [82.19, 93.41]
          110 |     87.46 | [81.79, 93.14]
          115 |     87.12 | [81.39, 92.86]
          120 |     86.79 | [80.98, 92.59]
          125 |     86.45 | [80.57, 92.32]
          130 |     86.11 | [80.16, 92.06]
          135 |     85.77 | [79.74, 91.80]
          140 |     85.43 | [79.33, 91.53]
          145 |     85.09 | [78.91, 91.27]
          150 |     84.75 | [78.49, 91.02]
          155 |     84.42 | [78.07, 90.76]
          160 |     84.08 | [77.64, 90.51]
          165 |     83.74 | [77.22, 90.26]
          170 |     83.40 | [76.79, 90.01]
      
      # neg_c_7 = 11.8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     91.11 | [86.06, 96.15]
            5 |     90.77 | [85.73, 95.80]
           10 |     90.43 | [85.40, 95.46]
           15 |     90.09 | [85.07, 95.11]
           20 |     89.75 | [84.73, 94.77]
           25 |     89.41 | [84.39, 94.44]
           30 |     89.07 | [84.04, 94.11]
           35 |     88.74 | [83.70, 93.78]
           40 |     88.40 | [83.34, 93.45]
           45 |     88.06 | [82.99, 93.13]
           50 |     87.72 | [82.63, 92.82]
           55 |     87.38 | [82.26, 92.50]
           60 |     87.04 | [81.89, 92.19]
           65 |     86.70 | [81.52, 91.89]
           70 |     86.37 | [81.15, 91.58]
           75 |     86.03 | [80.77, 91.28]
           80 |     85.69 | [80.39, 90.99]
           85 |     85.35 | [80.01, 90.69]
           90 |     85.01 | [79.62, 90.40]
           95 |     84.67 | [79.23, 90.12]
          100 |     84.33 | [78.84, 89.83]
          105 |     84.00 | [78.44, 89.55]
          110 |     83.66 | [78.04, 89.27]
          115 |     83.32 | [77.64, 89.00]
          120 |     82.98 | [77.23, 88.73]
          125 |     82.64 | [76.83, 88.46]
          130 |     82.30 | [76.42, 88.19]
          135 |     81.96 | [76.01, 87.92]
          140 |     81.63 | [75.59, 87.66]
          145 |     81.29 | [75.18, 87.40]
          150 |     80.95 | [74.76, 87.14]
          155 |     80.61 | [74.34, 86.88]
          160 |     80.27 | [73.91, 86.63]
          165 |     79.93 | [73.49, 86.38]
          170 |     79.59 | [73.06, 86.12]
      
      # neg_c_7 = 15.7
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     87.20 | [81.78, 92.62]
            5 |     86.86 | [81.46, 92.27]
           10 |     86.52 | [81.13, 91.92]
           15 |     86.18 | [80.80, 91.57]
           20 |     85.85 | [80.47, 91.23]
           25 |     85.51 | [80.13, 90.89]
           30 |     85.17 | [79.79, 90.55]
           35 |     84.83 | [79.44, 90.22]
           40 |     84.49 | [79.09, 89.89]
           45 |     84.15 | [78.74, 89.57]
           50 |     83.81 | [78.38, 89.24]
           55 |     83.48 | [78.03, 88.93]
           60 |     83.14 | [77.66, 88.61]
           65 |     82.80 | [77.30, 88.30]
           70 |     82.46 | [76.93, 87.99]
           75 |     82.12 | [76.56, 87.69]
           80 |     81.78 | [76.18, 87.39]
           85 |     81.44 | [75.80, 87.09]
           90 |     81.11 | [75.42, 86.79]
           95 |     80.77 | [75.04, 86.50]
          100 |     80.43 | [74.65, 86.21]
          105 |     80.09 | [74.26, 85.92]
          110 |     79.75 | [73.86, 85.64]
          115 |     79.41 | [73.47, 85.36]
          120 |     79.07 | [73.07, 85.08]
          125 |     78.74 | [72.67, 84.80]
          130 |     78.40 | [72.27, 84.53]
          135 |     78.06 | [71.86, 84.26]
          140 |     77.72 | [71.45, 83.99]
          145 |     77.38 | [71.04, 83.72]
          150 |     77.04 | [70.63, 83.46]
          155 |     76.70 | [70.21, 83.20]
          160 |     76.37 | [69.80, 82.93]
          165 |     76.03 | [69.38, 82.68]
          170 |     75.69 | [68.96, 82.42]
      
      Adjusted for:
      *  c82cop1 =                   3.13
      *   e42dep =            independent
      * c172code = low level of education

# ggpredict, print factors

    Code
      print(pr)
    Output
      # Predicted probabilities of bin_choice
      
      Wshort     | Predicted |       95% CI
      -------------------------------------
      climate    |      0.30 | [0.10, 0.62]
      cutwelfare |      0.67 | [0.33, 0.89]
      discipline |      0.79 | [0.51, 0.93]
      freedom    |      0.75 | [0.24, 0.97]
      ineqincOK  |      0.50 | [0.17, 0.83]
      leader     |      0.43 | [0.14, 0.77]
      police     |      0.75 | [0.38, 0.94]
      politduty  |      0.29 | [0.07, 0.67]
      refugees   |      0.50 | [0.17, 0.83]
      Russia     |      0.36 | [0.14, 0.66]
      taxesdown  |      0.29 | [0.07, 0.67]
      worse-off  |      0.45 | [0.20, 0.73]

---

    Code
      print(pr)
    Output
      # Predicted probabilities of bin_choice
      
      Wshort     | Predicted |       95% CI
      -------------------------------------
      climate    |      0.30 | [0.10, 0.62]
      cutwelfare |      0.67 | [0.33, 0.89]
      discipline |      0.79 | [0.51, 0.93]
      freedom    |      0.75 | [0.24, 0.97]
      ineqincOK  |      0.50 | [0.17, 0.83]
      leader     |      0.43 | [0.14, 0.77]
      police     |      0.75 | [0.38, 0.94]
      politduty  |      0.29 | [0.07, 0.67]
      refugees   |      0.50 | [0.17, 0.83]
      Russia     |      0.36 | [0.14, 0.66]
      taxesdown  |      0.29 | [0.07, 0.67]
      worse-off  |      0.45 | [0.20, 0.73]

==> ggeffects_1.3.4.tar.gz: ggeffects/tests/testthat/_snaps/print.md <==
# ggpredict, print

    Code
      print(ggpredict(fit, terms = c("c12hour", "neg_c_7", "c161sex")))
    Output
      # Predicted values of Total score BARTHEL INDEX
      
      # neg_c_7 = 8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.41 | [89.04, 99.77]
           45 |     91.36 | [85.91, 96.81]
           85 |     88.65 | [82.90, 94.40]
          170 |     82.89 | [75.94, 89.85]
      
      # neg_c_7 = 11.8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     90.60 | [85.18, 96.02]
           45 |     87.55 | [82.08, 93.03]
           85 |     84.85 | [79.09, 90.60]
          170 |     79.09 | [72.17, 86.00]
      
      # neg_c_7 = 15.7
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     86.70 | [80.89, 92.50]
           45 |     83.65 | [77.82, 89.48]
           85 |     80.94 | [74.87, 87.01]
          170 |     75.18 | [68.05, 82.32]
      
      # neg_c_7 = 8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.91 | [89.88, 99.95]
           45 |     91.86 | [86.78, 96.95]
           85 |     89.16 | [83.77, 94.54]
          170 |     83.40 | [76.79, 90.01]
      
      # neg_c_7 = 11.8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     91.11 | [86.06, 96.15]
           45 |     88.06 | [82.99, 93.13]
           85 |     85.35 | [80.01, 90.69]
          170 |     79.59 | [73.06, 86.12]
      
      # neg_c_7 = 15.7
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     87.20 | [81.78, 92.62]
           45 |     84.15 | [78.74, 89.57]
           85 |     81.44 | [75.80, 87.09]
          170 |     75.69 | [68.96, 82.42]
      
      Adjusted for:
      *  c82cop1 =                   3.13
      *   e42dep =            independent
      * c172code = low level of education
    Message
      
      Not all rows are shown in the output. Use `print(..., n = Inf)` to show
        all rows.

---

    Code
      print(ggpredict(fit, terms = c("c12hour", "neg_c_7", "c161sex")), n = Inf)
    Output
      # Predicted values of Total score BARTHEL INDEX
      
      # neg_c_7 = 8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.41 | [89.04, 99.77]
            5 |     94.07 | [88.71, 99.43]
           10 |     93.73 | [88.37, 99.09]
           15 |     93.39 | [88.03, 98.75]
           20 |     93.05 | [87.69, 98.42]
           25 |     92.71 | [87.34, 98.09]
           30 |     92.38 | [86.99, 97.76]
           35 |     92.04 | [86.63, 97.44]
           40 |     91.70 | [86.27, 97.12]
           45 |     91.36 | [85.91, 96.81]
           50 |     91.02 | [85.55, 96.50]
           55 |     90.68 | [85.18, 96.19]
           60 |     90.34 | [84.80, 95.88]
           65 |     90.01 | [84.43, 95.58]
           70 |     89.67 | [84.05, 95.28]
           75 |     89.33 | [83.67, 94.99]
           80 |     88.99 | [83.29, 94.69]
           85 |     88.65 | [82.90, 94.40]
           90 |     88.31 | [82.51, 94.12]
           95 |     87.97 | [82.11, 93.83]
          100 |     87.64 | [81.72, 93.55]
          105 |     87.30 | [81.32, 93.27]
          110 |     86.96 | [80.92, 93.00]
          115 |     86.62 | [80.52, 92.72]
          120 |     86.28 | [80.11, 92.45]
          125 |     85.94 | [79.70, 92.18]
          130 |     85.60 | [79.29, 91.92]
          135 |     85.26 | [78.88, 91.65]
          140 |     84.93 | [78.46, 91.39]
          145 |     84.59 | [78.05, 91.13]
          150 |     84.25 | [77.63, 90.87]
          155 |     83.91 | [77.21, 90.61]
          160 |     83.57 | [76.79, 90.36]
          165 |     83.23 | [76.36, 90.10]
          170 |     82.89 | [75.94, 89.85]
      
      # neg_c_7 = 11.8
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     90.60 | [85.18, 96.02]
            5 |     90.26 | [84.85, 95.67]
           10 |     89.92 | [84.52, 95.33]
           15 |     89.59 | [84.18, 94.99]
           20 |     89.25 | [83.84, 94.65]
           25 |     88.91 | [83.49, 94.32]
           30 |     88.57 | [83.15, 93.99]
           35 |     88.23 | [82.79, 93.67]
           40 |     87.89 | [82.44, 93.35]
           45 |     87.55 | [82.08, 93.03]
           50 |     87.22 | [81.72, 92.71]
           55 |     86.88 | [81.35, 92.40]
           60 |     86.54 | [80.98, 92.09]
           65 |     86.20 | [80.61, 91.79]
           70 |     85.86 | [80.24, 91.48]
           75 |     85.52 | [79.86, 91.19]
           80 |     85.18 | [79.48, 90.89]
           85 |     84.85 | [79.09, 90.60]
           90 |     84.51 | [78.71, 90.31]
           95 |     84.17 | [78.32, 90.02]
          100 |     83.83 | [77.92, 89.74]
          105 |     83.49 | [77.53, 89.45]
          110 |     83.15 | [77.13, 89.18]
          115 |     82.81 | [76.73, 88.90]
          120 |     82.48 | [76.33, 88.63]
          125 |     82.14 | [75.92, 88.35]
          130 |     81.80 | [75.51, 88.08]
          135 |     81.46 | [75.10, 87.82]
          140 |     81.12 | [74.69, 87.55]
          145 |     80.78 | [74.27, 87.29]
          150 |     80.44 | [73.86, 87.03]
          155 |     80.10 | [73.44, 86.77]
          160 |     79.77 | [73.02, 86.51]
          165 |     79.43 | [72.60, 86.26]
          170 |     79.09 | [72.17, 86.00]
      
      # neg_c_7 = 15.7
      # c161sex = [1] Male
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     86.70 | [80.89, 92.50]
            5 |     86.36 | [80.56, 92.15]
           10 |     86.02 | [80.23, 91.81]
           15 |     85.68 | [79.90, 91.46]
           20 |     85.34 | [79.56, 91.12]
           25 |     85.00 | [79.22, 90.79]
           30 |     84.66 | [78.87, 90.45]
           35 |     84.33 | [78.53, 90.13]
           40 |     83.99 | [78.17, 89.80]
           45 |     83.65 | [77.82, 89.48]
           50 |     83.31 | [77.46, 89.16]
           55 |     82.97 | [77.10, 88.84]
           60 |     82.63 | [76.74, 88.53]
           65 |     82.29 | [76.37, 88.22]
           70 |     81.96 | [76.00, 87.91]
           75 |     81.62 | [75.63, 87.61]
           80 |     81.28 | [75.25, 87.30]
           85 |     80.94 | [74.87, 87.01]
           90 |     80.60 | [74.49, 86.71]
           95 |     80.26 | [74.11, 86.42]
          100 |     79.92 | [73.72, 86.13]
          105 |     79.59 | [73.33, 85.84]
          110 |     79.25 | [72.94, 85.56]
          115 |     78.91 | [72.54, 85.28]
          120 |     78.57 | [72.14, 85.00]
          125 |     78.23 | [71.74, 84.72]
          130 |     77.89 | [71.34, 84.44]
          135 |     77.55 | [70.94, 84.17]
          140 |     77.21 | [70.53, 83.90]
          145 |     76.88 | [70.12, 83.63]
          150 |     76.54 | [69.71, 83.37]
          155 |     76.20 | [69.30, 83.10]
          160 |     75.86 | [68.88, 82.84]
          165 |     75.52 | [68.46, 82.58]
          170 |     75.18 | [68.05, 82.32]
      
      # neg_c_7 = 8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     94.91 | [89.88, 99.95]
            5 |     94.57 | [89.55, 99.60]
           10 |     94.23 | [89.22, 99.25]
           15 |     93.90 | [88.88, 98.91]
           20 |     93.56 | [88.54, 98.58]
           25 |     93.22 | [88.19, 98.25]
           30 |     92.88 | [87.84, 97.92]
           35 |     92.54 | [87.49, 97.59]
           40 |     92.20 | [87.13, 97.27]
           45 |     91.86 | [86.78, 96.95]
           50 |     91.53 | [86.41, 96.64]
           55 |     91.19 | [86.04, 96.33]
           60 |     90.85 | [85.67, 96.02]
           65 |     90.51 | [85.30, 95.72]
           70 |     90.17 | [84.92, 95.42]
           75 |     89.83 | [84.54, 95.12]
           80 |     89.49 | [84.16, 94.83]
           85 |     89.16 | [83.77, 94.54]
           90 |     88.82 | [83.38, 94.25]
           95 |     88.48 | [82.99, 93.97]
          100 |     88.14 | [82.59, 93.69]
          105 |     87.80 | [82.19, 93.41]
          110 |     87.46 | [81.79, 93.14]
          115 |     87.12 | [81.39, 92.86]
          120 |     86.79 | [80.98, 92.59]
          125 |     86.45 | [80.57, 92.32]
          130 |     86.11 | [80.16, 92.06]
          135 |     85.77 | [79.74, 91.80]
          140 |     85.43 | [79.33, 91.53]
          145 |     85.09 | [78.91, 91.27]
          150 |     84.75 | [78.49, 91.02]
          155 |     84.42 | [78.07, 90.76]
          160 |     84.08 | [77.64, 90.51]
          165 |     83.74 | [77.22, 90.26]
          170 |     83.40 | [76.79, 90.01]
      
      # neg_c_7 = 11.8
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     91.11 | [86.06, 96.15]
            5 |     90.77 | [85.73, 95.80]
           10 |     90.43 | [85.40, 95.46]
           15 |     90.09 | [85.07, 95.11]
           20 |     89.75 | [84.73, 94.77]
           25 |     89.41 | [84.39, 94.44]
           30 |     89.07 | [84.04, 94.11]
           35 |     88.74 | [83.70, 93.78]
           40 |     88.40 | [83.34, 93.45]
           45 |     88.06 | [82.99, 93.13]
           50 |     87.72 | [82.63, 92.82]
           55 |     87.38 | [82.26, 92.50]
           60 |     87.04 | [81.89, 92.19]
           65 |     86.70 | [81.52, 91.89]
           70 |     86.37 | [81.15, 91.58]
           75 |     86.03 | [80.77, 91.28]
           80 |     85.69 | [80.39, 90.99]
           85 |     85.35 | [80.01, 90.69]
           90 |     85.01 | [79.62, 90.40]
           95 |     84.67 | [79.23, 90.12]
          100 |     84.33 | [78.84, 89.83]
          105 |     84.00 | [78.44, 89.55]
          110 |     83.66 | [78.04, 89.27]
          115 |     83.32 | [77.64, 89.00]
          120 |     82.98 | [77.23, 88.73]
          125 |     82.64 | [76.83, 88.46]
          130 |     82.30 | [76.42, 88.19]
          135 |     81.96 | [76.01, 87.92]
          140 |     81.63 | [75.59, 87.66]
          145 |     81.29 | [75.18, 87.40]
          150 |     80.95 | [74.76, 87.14]
          155 |     80.61 | [74.34, 86.88]
          160 |     80.27 | [73.91, 86.63]
          165 |     79.93 | [73.49, 86.38]
          170 |     79.59 | [73.06, 86.12]
      
      # neg_c_7 = 15.7
      # c161sex = [2] Female
      
      c12hour | Predicted |         95% CI
      ------------------------------------
            0 |     87.20 | [81.78, 92.62]
            5 |     86.86 | [81.46, 92.27]
           10 |     86.52 | [81.13, 91.92]
           15 |     86.18 | [80.80, 91.57]
           20 |     85.85 | [80.47, 91.23]
           25 |     85.51 | [80.13, 90.89]
           30 |     85.17 | [79.79, 90.55]
           35 |     84.83 | [79.44, 90.22]
           40 |     84.49 | [79.09, 89.89]
           45 |     84.15 | [78.74, 89.57]
           50 |     83.81 | [78.38, 89.24]
           55 |     83.48 | [78.03, 88.93]
           60 |     83.14 | [77.66, 88.61]
           65 |     82.80 | [77.30, 88.30]
           70 |     82.46 | [76.93, 87.99]
           75 |     82.12 | [76.56, 87.69]
           80 |     81.78 | [76.18, 87.39]
           85 |     81.44 | [75.80, 87.09]
           90 |     81.11 | [75.42, 86.79]
           95 |     80.77 | [75.04, 86.50]
          100 |     80.43 | [74.65, 86.21]
          105 |     80.09 | [74.26, 85.92]
          110 |     79.75 | [73.86, 85.64]
          115 |     79.41 | [73.47, 85.36]
          120 |     79.07 | [73.07, 85.08]
          125 |     78.74 | [72.67, 84.80]
          130 |     78.40 | [72.27, 84.53]
          135 |     78.06 | [71.86, 84.26]
          140 |     77.72 | [71.45, 83.99]
          145 |     77.38 | [71.04, 83.72]
          150 |     77.04 | [70.63, 83.46]
          155 |     76.70 | [70.21, 83.20]
          160 |     76.37 | [69.80, 82.93]
          165 |     76.03 | [69.38, 82.68]
          170 |     75.69 | [68.96, 82.42]
      
      Adjusted for:
      *  c82cop1 =                   3.13
      *   e42dep =            independent
      * c172code = low level of education

# ggpredict, print factors

    Code
      print(pr)
    Output
      # Predicted probabilities of bin_choice
      
      Wshort     | Predicted |       95% CI
      -------------------------------------
      climate    |      0.30 | [0.10, 0.62]
      cutwelfare |      0.67 | [0.33, 0.89]
      discipline |      0.79 | [0.51, 0.93]
      freedom    |      0.75 | [0.24, 0.97]
      ineqincOK  |      0.50 | [0.17, 0.83]
      leader     |      0.43 | [0.14, 0.77]
      police     |      0.75 | [0.38, 0.94]
      politduty  |      0.29 | [0.07, 0.67]
      refugees   |      0.50 | [0.17, 0.83]
      Russia     |      0.36 | [0.14, 0.66]
      taxesdown  |      0.29 | [0.07, 0.67]
      worse-off  |      0.45 | [0.20, 0.73]

---

    Code
      print(pr)
    Output
      # Predicted probabilities of bin_choice
      
      Wshort     | Predicted |       95% CI
      -------------------------------------
      climate    |      0.30 | [0.10, 0.62]
      cutwelfare |      0.67 | [0.33, 0.89]
      discipline |      0.79 | [0.51, 0.93]
      freedom    |      0.75 | [0.24, 0.97]
      ineqincOK  |      0.50 | [0.17, 0.83]
      leader     |      0.43 | [0.14, 0.77]
      police     |      0.75 | [0.38, 0.94]
      politduty  |      0.29 | [0.07, 0.67]
      refugees   |      0.50 | [0.17, 0.83]
      Russia     |      0.36 | [0.14, 0.66]
      taxesdown  |      0.29 | [0.07, 0.67]
      worse-off  |      0.45 | [0.20, 0.73]
